@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import re
-from typing import Any, Union, Pattern, Match, Callable
+from typing import Any, Union, Pattern, Match, Callable, Optional
 
 
 __RE_FLAGS = [ re.UNICODE, ( re.IGNORECASE + re.UNICODE) ]
@@ -82,7 +82,8 @@ def is_match_string(
     if pattern == string:
         return True
     else:
-        if not isinstance(string, str):
+        if not ( isinstance(string, str)
+                 and isinstance(pattern, (str, Pattern))):
             return False
 
         match = re.search(pattern, string, flags = __RE_FLAGS[wild])
@@ -92,7 +93,7 @@ def is_match_string(
             return False
 
 
-def remove_accents(self, data: Any) -> Any:
+def remove_accents(data: Any) -> Any:
     """Return the normal form for a Unicode string
        using canonical decomposition."""
 
@@ -102,3 +103,21 @@ def remove_accents(self, data: Any) -> Any:
                  .decode("ascii") )
     return data
 
+def remove_character(
+        string: str,
+        punctuations_list: Optional[list]=None
+    ) ->str:
+    if not stop_words_list:
+        return string
+    else:
+        return "".join([letter for letter in string.lower() if letter not in punctuations_list])
+
+def remove_words(
+        string: str,
+        stop_words_list: Optional[list]=None
+    ) ->str:
+    if not stop_words_list:
+        return string
+    else:
+        return " ".join([word for word in give_string.split(" ") if word not in stopwords_list])
+
